Function Reference.reference
Increments the internal reference counter. Use this only if you really know what you are doing.
Returns true if the increment was successful, false otherwise.
bool reference() nothrow @nogc;
Increments the internal reference counter. Use this only if you really know what you are doing.
Returns true if the increment was successful, false otherwise.
bool reference() nothrow @nogc;