Function Reference.unreference
Decrements the internal reference counter. Use this only if you really know what you are doing.
Returns true if the decrement was successful, false otherwise.
bool unreference() nothrow @nogc;
Decrements the internal reference counter. Use this only if you really know what you are doing.
Returns true if the decrement was successful, false otherwise.
bool unreference() nothrow @nogc;